@@ -4,6 +4,7 @@ The main module of VenviPy.
 """
 import sys
 import os
+import csv
 from pathlib import Path
 
 # need to set the correct cwd
@@ -45,9 +46,9 @@ from PyQt5.QtWidgets import (
 import venvipy_rc  # pylint: disable=unused-import
 
 from get_data import (
-    get_python_installs,
     get_active_dir,
-    get_active_dir_str
+    get_active_dir_str,
+    get_python_installs
 )
 from dialogs import InfoAboutVenviPy
 from tables import VenvTable
@@ -199,12 +200,12 @@ class MainWindow(QMainWindow):
         )
         self.new_venv_button.setMinimumSize(QSize(135, 0))
 
-        self.search_pypi_button = QPushButton(
-            "&Search PyPI",
-            centralwidget,
-            statusTip="Search the Python Package Index",
-            clicked=self.search_pypi
-        )
+        #self.search_pypi_button = QPushButton(
+            #"&Search PyPI",
+            #centralwidget,
+            #statusTip="Search the Python Package Index",
+            #clicked=self.search_pypi
+        #)
 
         self.exit_button = QPushButton(
             "Quit",
@@ -242,7 +243,7 @@ class MainWindow(QMainWindow):
         v_layout_2.addWidget(self.logo)
         v_layout_2.addWidget(self.add_interpreter_button)
         v_layout_2.addWidget(self.new_venv_button)
-        v_layout_2.addWidget(self.search_pypi_button)
+        #v_layout_2.addWidget(self.search_pypi_button)
         v_layout_2.addItem(spacer_item_1)
         v_layout_2.addWidget(self.exit_button)
 
@@ -269,10 +270,8 @@ class MainWindow(QMainWindow):
             alternatingRowColors=True
         )
 
-        # adjust vertical headers
-        v_header_interpreter_table = interpreter_table.verticalHeader()
-        v_header_interpreter_table.setDefaultSectionSize(27)
-        v_header_interpreter_table.hide()
+        # hide vertical header
+        interpreter_table.verticalHeader().hide()
 
         # adjust (horizontal) headers
         h_header_interpreter_table = interpreter_table.horizontalHeader()
@@ -307,21 +306,19 @@ class MainWindow(QMainWindow):
             refresh=self.pop_venv_table
         )
 
-        # adjust vertical headers
-        v_header_venv_table = self.venv_table.verticalHeader()
-        v_header_venv_table.setDefaultSectionSize(27)
-        v_header_venv_table.hide()
+        # hide vertical header
+        self.venv_table.verticalHeader().hide()
 
-        # adjust (horizontal) headers
+        # adjust horizontal headers
         h_header_venv_table = self.venv_table.horizontalHeader()
         h_header_venv_table.setDefaultAlignment(Qt.AlignLeft)
-        h_header_venv_table.setDefaultSectionSize(180)
+        h_header_venv_table.setDefaultSectionSize(120)
         h_header_venv_table.setStretchLastSection(True)
 
         # set table view model
-        self.model_venv_table = QStandardItemModel(0, 2, centralwidget)
+        self.model_venv_table = QStandardItemModel(0, 3, centralwidget)
         self.model_venv_table.setHorizontalHeaderLabels(
-            ["Venv Name", "Version"]
+            ["Venv", "Version", "Packages", "installed"]
         )
         self.venv_table.setModel(self.model_venv_table)
 
@@ -363,14 +360,14 @@ class MainWindow(QMainWindow):
             triggered=self.venv_wizard.exec_
         )
 
-        self.action_search_pypi = QAction(
-            manage_icon,
-            "&Search PyPI",
-            self,
-            statusTip="Search the Python Package Index",
-            shortcut="Ctrl+S",
-            triggered=self.search_pypi
-        )
+        #self.action_search_pypi = QAction(
+            #manage_icon,
+            #"&Search PyPI",
+            #self,
+            #statusTip="Search the Python Package Index",
+            #shortcut="Ctrl+S",
+            #triggered=self.search_pypi
+        #)
 
         self.action_select_active_dir = QAction(
             folder_icon,
@@ -428,9 +425,9 @@ class MainWindow(QMainWindow):
         menu_venv.addAction(self.action_exit)
         menu_bar.addAction(menu_venv.menuAction())
 
-        menu_extras = QMenu("&Extras", menu_bar)
-        menu_extras.addAction(self.action_search_pypi)
-        menu_bar.addAction(menu_extras.menuAction())
+        #menu_extras = QMenu("&Extras", menu_bar)
+        #menu_extras.addAction(self.action_search_pypi)
+        #menu_bar.addAction(menu_extras.menuAction())
 
         menu_help = QMenu("&Help", menu_bar)
         menu_help.addAction(self.action_about_venvipy)
@@ -450,8 +447,14 @@ class MainWindow(QMainWindow):
             self
         )
 
-        if not get_python_installs():
-            self.launching_without_python()
+        # check if any Python is installed
+        csv_file = os.path.expanduser("~/.venvipy/py-installs")
+        if os.path.isfile(csv_file):
+            info = []
+            with open(csv_file, newline="") as cf:
+                reader = csv.DictReader(cf, delimiter=",")
+                if reader is None:
+                    self.launching_without_python()
 
 
     def info_about_qt(self):
@@ -495,38 +498,32 @@ class MainWindow(QMainWindow):
 
 
     def enable_features(self, state):
-        self.search_pypi_button.setEnabled(state)
-        self.action_search_pypi.setEnabled(state)
+        #self.search_pypi_button.setEnabled(state)
+        #self.action_search_pypi.setEnabled(state)
         self.venv_table.setEnabled(state)
 
 
     @pyqtSlot(str)
-    def pop_interpreter_table(self, custom_path):
+    def pop_interpreter_table(self):
         """
         Populate the interpreter table view.
         """
-        if custom_path != "":
-            if get_python_installs(custom_path):
-                self.model_interpreter_table.setRowCount(0)
+        csv_file = os.path.expanduser("~/.venvipy/py-installs")
 
-            for info in get_python_installs(custom_path):
-                self.model_interpreter_table.insertRow(0)
-                for i, text in enumerate((info.py_version, info.py_path)):
-                    self.model_interpreter_table.setItem(
-                        0, i, QStandardItem(text)
-                    )
-                print(f"[PYTHON]: {info}")
-        else:
-            if get_python_installs():
+        if os.path.isfile(csv_file):
+            info = []
+            with open(csv_file, newline="") as cf:
+                reader = csv.DictReader(cf, delimiter=",")
                 self.model_interpreter_table.setRowCount(0)
-
-            for info in get_python_installs():
-                self.model_interpreter_table.insertRow(0)
-                for i, text in enumerate((info.py_version, info.py_path)):
-                    self.model_interpreter_table.setItem(
-                        0, i, QStandardItem(text)
-                    )
-                print(f"[PYTHON]: {info}")
+                for info in reader:
+                    self.model_interpreter_table.insertRow(0)
+                    for i, text in enumerate(
+                        (info["PYTHON_VERSION"], info["PYTHON_PATH"])
+                    ):
+                        self.model_interpreter_table.setItem(
+                            0, i, QStandardItem(text)
+                        )
+                    print(f"[PYTHON]: {info}")
 
 
     def pop_venv_table(self):
@@ -537,7 +534,12 @@ class MainWindow(QMainWindow):
 
         for info in get_active_dir():
             self.model_venv_table.insertRow(0)
-            for i, text in enumerate((info.venv_name, info.venv_version)):
+            for i, text in enumerate((
+                info.venv_name,
+                info.venv_version,
+                info.system_site_packages,
+                info.is_on_system
+            )):
                 self.model_venv_table.setItem(0, i, QStandardItem(text))
             print(f"[VENV]: {info}")
 
@@ -592,7 +594,8 @@ def main():
     os.system("clear")
 
     main_window = MainWindow()
-    main_window.pop_interpreter_table(None)
+    get_python_installs()
+    main_window.pop_interpreter_table()
     main_window.pop_venv_table()
     main_window.update_label()
     main_window.show()
