@@ -3,9 +3,16 @@
 This module contains the wizard for creating
 and setting up virtual environments.
 """
-from functools import partial
 import sys
 import os
+import csv
+from functools import partial
+from pathlib import Path
+
+# need to set the correct cwd
+CURRENT_DIR = Path(__file__).parent
+sys.path.insert(0, str(CURRENT_DIR))
+os.chdir(CURRENT_DIR)
 
 from PyQt5.QtCore import Qt, pyqtSignal, QTimer, QThread
 from PyQt5.QtGui import (
@@ -43,7 +50,6 @@ from manage_pip import PipManager
 from tables import ResultsTable
 from get_data import (
     get_module_infos,
-    get_python_installs,
     get_python_version
 )
 from creator import (
@@ -70,7 +76,7 @@ class VenvWizard(QWizard):
     def __init__(self):
         super().__init__()
 
-        self.setWindowTitle("Venv Wizard")
+        self.setWindowTitle("VenviPy - Venv Wizard")
         self.resize(680, 510)
         self.center()
         self.setWindowIcon(QIcon(":/img/profile.png"))
@@ -186,6 +192,10 @@ class BasicSettings(QWizardPage):
         self.m_install_venv_worker.finished.connect(self.progress_bar.close)
         self.m_install_venv_worker.finished.connect(self.finish_info)
 
+        # perform a proper stop using quit() and wait()
+        self.thread.finished.connect(self.thread.quit)
+        self.thread.finished.connect(self.thread.wait)
+
 
         #]===================================================================[#
         #] PAGE CONTENT [#===================================================[#
@@ -242,6 +252,7 @@ class BasicSettings(QWizardPage):
         self.site_pkgs_check_box = QCheckBox(
             "&Make system (global) site-packages dir available to venv"
         )
+        # since we are on linux we don't really need this :D
         self.symlinks_check_box = QCheckBox(
             "Attempt to &symlink rather than copy files into venv"
         )
@@ -293,7 +304,7 @@ class BasicSettings(QWizardPage):
         group_box_layout = QVBoxLayout()
         group_box_layout.addWidget(self.with_pip_check_box)
         group_box_layout.addWidget(self.site_pkgs_check_box)
-        group_box_layout.addWidget(self.symlinks_check_box)
+        #group_box_layout.addWidget(self.symlinks_check_box)
         group_box.setLayout(group_box_layout)
 
 
@@ -308,10 +319,18 @@ class BasicSettings(QWizardPage):
         """
         Add the found Python versions to combo box
         """
-        for info in get_python_installs():
-            self.interpreter_combo_box.addItem(
-                f"{info.py_version}  ->  {info.py_path}", info.py_path
-            )
+        csv_file = os.path.expanduser("~/.venvipy/py-installs")
+
+        if os.path.isfile(csv_file):
+            info = []
+            with open(csv_file, newline="") as cf:
+                reader = csv.DictReader(cf, delimiter=",")
+
+                for info in reader:
+                    self.interpreter_combo_box.addItem(
+                        f'{info["PYTHON_VERSION"]}  ->  {info["PYTHON_PATH"]}',
+                        info["PYTHON_PATH"]
+                    )
 
 
     def select_python(self):
@@ -331,9 +350,19 @@ class BasicSettings(QWizardPage):
 
         if bin_file != "":
             custom_version = get_python_version(bin_file)
-            self.interpreter_combo_box.addItem(
-                f"{custom_version}  ->  {bin_file}", bin_file
-            )
+            csv_file = os.path.expanduser("~/.venvipy/py-installs")
+            with open(csv_file, "a", newline="") as cf:
+                fields = ["PYTHON_VERSION", "PYTHON_PATH"]
+                writer = csv.DictWriter(
+                    cf, delimiter=",", quoting=csv.QUOTE_ALL, fieldnames=fields
+                )
+                writer.writerow({
+                    "PYTHON_VERSION": custom_version,
+                    "PYTHON_PATH": bin_file
+                })
+                self.interpreter_combo_box.addItem(
+                    f"{custom_version}  ->  {bin_file}", bin_file
+                )
         # transmit bin_file to pop_interpreter_table() in MainWindow
         self.wizard().update_table.emit(bin_file)
         return bin_file
@@ -773,7 +802,6 @@ class FinalPage(QWizardPage):
 
         # call update_zen_line to get a different line every new session
         self.wizard().refresh.connect(self.update_zen_line)
-
         self.wizard().refresh.emit()
 
 
